Class: Google::Apis::ApigatewayV1::ApigatewayOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigateway_v1/classes.rb,
lib/google/apis/apigateway_v1/representations.rb,
lib/google/apis/apigateway_v1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApigatewayOperation

Returns a new instance of ApigatewayOperation.



810
811
812
# File 'lib/google/apis/apigateway_v1/classes.rb', line 810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


771
772
773
# File 'lib/google/apis/apigateway_v1/classes.rb', line 771

def done
  @done
end

#errorGoogle::Apis::ApigatewayV1::ApigatewayStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



782
783
784
# File 'lib/google/apis/apigateway_v1/classes.rb', line 782

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


790
791
792
# File 'lib/google/apis/apigateway_v1/classes.rb', line 790

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


797
798
799
# File 'lib/google/apis/apigateway_v1/classes.rb', line 797

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


808
809
810
# File 'lib/google/apis/apigateway_v1/classes.rb', line 808

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



815
816
817
818
819
820
821
# File 'lib/google/apis/apigateway_v1/classes.rb', line 815

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end