Class: Google::Apis::ApigatewayV1::ApigatewayOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigateway_v1/classes.rb,
lib/google/apis/apigateway_v1/representations.rb,
lib/google/apis/apigateway_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApigatewayOperationMetadata

Returns a new instance of ApigatewayOperationMetadata.



873
874
875
# File 'lib/google/apis/apigateway_v1/classes.rb', line 873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


831
832
833
# File 'lib/google/apis/apigateway_v1/classes.rb', line 831

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


836
837
838
# File 'lib/google/apis/apigateway_v1/classes.rb', line 836

def create_time
  @create_time
end

#diagnosticsArray<Google::Apis::ApigatewayV1::ApigatewayOperationMetadataDiagnostic>

Output only. Diagnostics generated during processing of configuration source files. Corresponds to the JSON property diagnostics



842
843
844
# File 'lib/google/apis/apigateway_v1/classes.rb', line 842

def diagnostics
  @diagnostics
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


847
848
849
# File 'lib/google/apis/apigateway_v1/classes.rb', line 847

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


855
856
857
# File 'lib/google/apis/apigateway_v1/classes.rb', line 855

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


861
862
863
# File 'lib/google/apis/apigateway_v1/classes.rb', line 861

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


866
867
868
# File 'lib/google/apis/apigateway_v1/classes.rb', line 866

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


871
872
873
# File 'lib/google/apis/apigateway_v1/classes.rb', line 871

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



878
879
880
881
882
883
884
885
886
887
# File 'lib/google/apis/apigateway_v1/classes.rb', line 878

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end