Class: Google::Apis::ApigatewayV1::ApigatewayService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApigatewayV1::ApigatewayService
- Defined in:
- lib/google/apis/apigateway_v1/service.rb
Overview
API Gateway API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apigateway.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new Api in a given project and location.
-
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
-
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new Gateway in a given project and location.
-
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single Api.
-
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single ApiConfig.
-
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single Gateway.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayLocation
Gets information about a location.
-
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayApi
Gets details of a single Api.
-
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayApiConfig
Gets details of a single ApiConfig.
-
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayGateway
Gets details of a single Gateway.
-
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ ApigatewayService
constructor
A new instance of ApigatewayService.
-
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
-
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListApisResponse
Lists Apis in a given project and location.
-
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single Api.
-
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single ApiConfig.
-
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single Gateway.
-
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ ApigatewayService
Returns a new instance of ApigatewayService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apigateway_v1', client_version: Google::Apis::ApigatewayV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 1075 def cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayCancelOperationRequest::Representation command.request_object = apigateway_cancel_operation_request_object command.response_representation = Google::Apis::ApigatewayV1::Empty::Representation command.response_class = Google::Apis::ApigatewayV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new Api in a given project and location.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 160 def create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/apis', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiId'] = api_id unless api_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 462 def create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/configs', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiConfigId'] = api_config_id unless api_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Creates a new Gateway in a given project and location.
770 771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 770 def create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/gateways', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['gatewayId'] = gateway_id unless gateway_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single Api.
193 194 195 196 197 198 199 200 201 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 193 def delete_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single ApiConfig.
496 497 498 499 500 501 502 503 504 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 496 def delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Deletes a single Gateway.
803 804 805 806 807 808 809 810 811 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 803 def delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 1110 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::Empty::Representation command.response_class = Google::Apis::ApigatewayV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayLocation
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayLocation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayLocation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayApi
Gets details of a single Api.
223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 223 def get_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayApi::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayApi command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayApiConfig
Gets details of a single ApiConfig.
530 531 532 533 534 535 536 537 538 539 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 530 def get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayApiConfig::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayApiConfig command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
575 576 577 578 579 580 581 582 583 584 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 575 def get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
267 268 269 270 271 272 273 274 275 276 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 267 def get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayGateway
Gets details of a single Gateway.
833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 833 def get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayGateway::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayGateway command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 877 def get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1141 1142 1143 1144 1145 1146 1147 1148 1149 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 1141 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
615 616 617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 615 def list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/configs', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayListApiConfigsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayListApiConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListApisResponse
Lists Apis in a given project and location.
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 307 def list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/apis', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayListApisResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayListApisResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
916 917 918 919 920 921 922 923 924 925 926 927 928 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 916 def list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/gateways', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayListGatewaysResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayListGatewaysResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 1186 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayListOperationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 121 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ApigatewayV1::ApigatewayListLocationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single Api.
348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 348 def patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single ApiConfig.
657 658 659 660 661 662 663 664 665 666 667 668 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 657 def patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayOperation
Updates the parameters of a single Gateway.
958 959 960 961 962 963 964 965 966 967 968 969 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 958 def patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 695 def set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 386 def set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 996 def set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 734 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 425 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/google/apis/apigateway_v1/service.rb', line 1035 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |